@@ -14,6 +14,7 @@ logger = logging.getLogger(__name__)
 TEMPLATE_DATA = {
     "author": "Author",
     "source": "Source",
+    "published": "Published",
 }
 
 
@@ -21,7 +22,9 @@ TEMPLATE_DATA = {
 class FeedConfig:
     name: str
     source: str
+    enable: bool = True
     save_bandwith: bool = True
+    notification: Optional[bool] = None
     etag: Optional[str] = None
     modified: Optional[str] = None
     web_page_preview: Optional[bool] = None
@@ -37,6 +40,7 @@ class FeedConfig:
 class Config:
     bot_token: str = ""
     env_token: str = "TOKEN"
+    notification: bool = True
     web_page_preview: bool = True
     message_delay: float = 0.05
     read_more_button: str = "Read more..."
